@@ -1,15 +1,18 @@
+# -*- coding: utf-8 -*-
 """Google Cloud DNS API."""
 
 from bits.google.services.base import Base
 from googleapiclient.discovery import build
+from google.cloud.dns import client
 
 
 class CloudDNS(Base):
     """CloudDNS class."""
 
-    def __init__(self, credentials):
+    def __init__(self, credentials=None, project=None):
         """Initialize a class instance."""
         self.dns = build('dns', 'v1', credentials=credentials)
+        self.client = client.Client(project)
 
     def get_managed_zones(self, project):
         """Return list of DNS managed zones."""
